==> spip_4.1.11+dfsg.orig.tar.xz: plugins-dist/mots/lang/adminmots_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/adminmots?lang_cible=es
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_associer' => 'Relacionar',
	'bouton_dissocier' => 'Desvincular',
	'bouton_fusionner' => 'Fusionar',

	// E
	'erreur_admin_mot_action_inconnue' => '¿Qué quiere hacer?',
	'erreur_mot_cle_deja' => 'Imposible: ya es la palabra clave en la que estás.',
	'erreur_selection_id' => 'Seleccione una palabra clave o introduzca su ID en el campo de entrada',

	// I
	'icone_administrer_mot' => 'Administración avanzada.',

	// L
	'label_associer_objets_mot' => '<b>Asociar</b> esta palabra clave con objetos que ya tienen la palabra clave',
	'label_confirm_fusion' => 'Esta operación no se puede deshacer.<br />
<strong>La palabra clave actual #@id_mot@ será eliminada</strong> y los siguientes enlaces serán transferidos a la palabra #@id_mot_new@: ',
	'label_confirm_fusion_check' => 'Verifica la fusión de la palabra #@id_mot@ con la palabra #@id_mot_new@',
	'label_dissocier_objets_mot' => '<b>Desvincular</b> esta palabra clave de los objetos que también tienen la palabra clave',
	'label_fusionner_mot' => '<b>Fusionar</b> con la palabra clave',
	'label_mot_1_enfant' => 'Hijo:',
	'label_mot_nb_enfants' => 'Hijos:',
	'label_mot_parent' => 'Padre:',

	// P
	'placeholder_id_mot' => 'o #ID_MOT',
	'placeholder_select' => 'Seleccionar…',

	// R
	'result_associer_nb' => ' se han asociado a esta palabra clave',
	'result_associer_ras' => 'Nada que hacer: todos los objetos ya tienen esta palabra clave',
	'result_cancel_ok' => 'La última operación fue cancelada.',
	'result_dissocier_nb' => ' se han disociado de esta palabra clave',
	'result_dissocier_ras' => 'Nada que hacer: no hay ningún objeto relevante asociado a esta palabra clave',
	'result_fusionner_ok' => 'Ahora puede eliminar esta palabra clave: todos los enlaces se han transferido a la otra palabra clave @mot@.',

	// T
	'titre_formulaire_administrer_mot' => 'Administrar la palabra clave'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/mots/lang/adminmots_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/adminmots?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_associer' => 'Relacionar',
	'bouton_dissocier' => 'Desvincular',
	'bouton_fusionner' => 'Fusionar',

	// E
	'erreur_admin_mot_action_inconnue' => '¿Qué quiere hacer?',
	'erreur_mot_cle_deja' => 'Imposible: ya es la palabra clave en la que estás.',
	'erreur_selection_id' => 'Seleccione una palabra clave o introduzca su ID en el campo de entrada',

	// I
	'icone_administrer_mot' => 'Administración avanzada.',

	// L
	'label_associer_objets_mot' => '<b>Asociar</b> esta palabra clave con objetos que ya tienen la palabra clave',
	'label_confirm_fusion' => 'Esta operación no se puede deshacer.<br />
<strong>La palabra clave actual #@id_mot@ será eliminada</strong> y los siguientes enlaces serán transferidos a la palabra #@id_mot_new@: ',
	'label_confirm_fusion_check' => 'Verifica la fusión de la palabra #@id_mot@ con la palabra #@id_mot_new@',
	'label_dissocier_objets_mot' => '<b>Desvincular</b> esta palabra clave de los objetos que también tienen la palabra clave',
	'label_fusionner_mot' => '<b>Fusionar</b> con la palabra clave',
	'label_mot_1_enfant' => 'Hijo:',
	'label_mot_nb_enfants' => 'Hijos:',
	'label_mot_parent' => 'Padre:',

	// P
	'placeholder_id_mot' => 'o #ID_MOT',
	'placeholder_select' => 'Seleccionar…',

	// R
	'result_associer_nb' => ' se han asociado a esta palabra clave',
	'result_associer_ras' => 'Nada que hacer: todos los objetos ya tienen esta palabra clave',
	'result_cancel_ok' => 'La última operación fue cancelada.',
	'result_dissocier_nb' => ' se han disociado de esta palabra clave',
	'result_dissocier_ras' => 'Nada que hacer: no hay ningún objeto relevante asociado a esta palabra clave',
	'result_fusionner_ok' => 'Ahora puede eliminar esta palabra clave: todos los enlaces se han transferido a la otra palabra clave @mot@.',

	// T
	'titre_formulaire_administrer_mot' => 'Administrar la palabra clave',
];
